This function accepts a data.frame with one row representing each
parent record returned by a query with a corresponding list element in the
list of child record results stored as tbl_df in a list.
combine_parent_and_child_resultsets(parents_df, child_df_list)tbl_df; a dataset with 1 row per parent record from
the query recordset, that can be joined with its corresponding child records.
list of tbl_df; a list of child records that
is the same length as the number of rows in the parent_df.