drop_nested_child_records: Drop nested child records in a record
Description
This function accepts a single record from a nested query and removes the element
with nested "records" which represent the child records belonging to the parent.
Usage
drop_nested_child_records(x)
Arguments
x
list; a list parsed from JSON and representing one individual
parent query record.
Value
list; a list without any elements that have nested child records
assuming they have already been extracted.