extract_nested_child_records: Extract nested child records in a record
Description
This function accepts a single record from a nested query and "unpacks" the
"records" which represent the child records belonging to the parent.
Usage
extract_nested_child_records(x)
Arguments
x
list; a list parsed from an HTTP response and representing
one individual parent query record.
Value
tbl_df; a data frame with each row representing a child record.