Check that token appears to be legitimate
is_legit_token(x, verbose = FALSE)an object that is supposed to be an object of class Token2.0
(an S3 class provided by httr). If so, the result will return TRUE.
logical; an indicator of whether to print additional
detail for each API call, which is useful for debugging. More specifically, when
set to TRUE the URL, header, and body will be printed for each request,
along with additional diagnostic information where available.
logical