Learn R Programming

salesforcer (version 1.0.1)

make_analytics_folder_share_by_id_url: Analytics Folder share by Id URL generator

Description

Analytics Folder share by Id URL generator

Usage

make_analytics_folder_share_by_id_url(report_folder_id, share_id)

Arguments

report_folder_id

character; the Salesforce Id assigned to a created analytics folder (it will start with "00l").

share_id

character; the Salesforce Id assigned to a created analytics folder share (it will start with "004").

Value

character; a complete URL (as a string) that will be used to send Analytics folder calls to. This URL is specific to your instance and the API version being used.