Learn R Programming

salesforcer (version 1.0.1)

make_analytics_notifications_limits_url: Analytics Notification limits URL generator

Description

Analytics Notification limits URL generator

Usage

make_analytics_notifications_limits_url()

Arguments

Value

character; a complete URL (as a string) that will be used to send Analytics notification calls to. This URL is specific to your instance and the API version being used.