Bulk Get Job Generic URL Generator
make_bulk_get_job_url(
job_id,
api_type = c("Bulk 1.0", "Bulk 2.0"),
query_operation = NULL
)character; the Salesforce Id assigned to a submitted job as
returned by sf_create_job_bulk. It will start with "750".
character; a string indicating which Bulk API to execute
the call against.
logical; an indicator of whether the call is
for a query or another operation, such as, CRUD operations.
character; a complete URL (as a string) that will be used to
send subsequent Bulk API calls to. This URL is specific to your instance and
the API version being used.