powered by
Report Query URL generator
make_report_query_url()
character; a complete URL (as a string) that will be used to send Reports and Dashboards API calls to. This URL is specific to your instance and the API version being used.
character