This function converts a list of metadata to XML
build_metadata_xml_from_list(
input_data,
metatype = NULL,
root_name = NULL,
ns = c(character(0)),
root = NULL
)XML document serving as the basis upon which to add the list
a character indicating the element name of each record in the list
character; the name of the root node if created
named vector; a collection of character strings indicating the namespace definitions of the root node if created
XMLNode; a node to be used as the root
A XML document with the sublist data added